Documentation
¶
Index ¶
- func AskRemote(remotes []*git.Remote) string
- func GetPathParam(context *cli.Context) (string, error)
- func GetRemotePath(remote string) string
- func GetRemotes() []*git.Remote
- func IsGitRepository() bool
- func ReadInt() int
- func ReadLine() string
- func ReadLineOptional(defaultValue string) string
- func RepoCommits() object.CommitIter
- func RepoHead() *plumbing.Reference
- func RepoLastCommit() *object.Commit
- func Repository() *git.Repository
- func ShowSpinner() *spinner.Spinner
- func Ternary(condition bool, value1 interface{}, value2 interface{}) interface{}
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetPathParam ¶
GetPathParam find path repository in command line arg or in the directory
func GetRemotePath ¶
GetRemotePath returns a string with the repo path for the given remote repository
func GetRemotes ¶
GetRemotes returns an array with references to remote repositories
func IsGitRepository ¶
func IsGitRepository() bool
IsGitRepository returns true if the current working directory is a valid git repository
func ReadLineOptional ¶
ReadLineOptional read text from stdin until break line, if the input is empty, return a default value
func RepoCommits ¶
func RepoCommits() object.CommitIter
RepoCommits return repository commits iterator
func RepoLastCommit ¶
RepoLastCommit return last commit in git repository
func ShowSpinner ¶
ShowSpinner display and return spinner instance
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.